<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       developress.it/roberto_paolucci
 * @since      1.0.0
 *
 * @package    Developress_sticky_footer_bar
 * @subpackage Developress_sticky_footer_bar/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Developress_sticky_footer_bar
 * @subpackage Developress_sticky_footer_bar/admin
 * @author     Roberto Paolucci <robertopaolucci805@gmail.com>
 */
class Developress_sticky_footer_bar_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * The options name to be used in this plugin
	 *
	 * @since  	1.0.0
	 * @access 	private
	 * @var  	string 		$option_name 	Option name of this plugin
	*/
	private $option_name = 'developressbar_setting';

	private $setting_options = array('url_1', 'text_1', 'url_2', 'text_2', 'url_3', 'text_3', 'url_4', 'text_4');
	/**
 * Register the setting parameters
 *
 * @since  	1.0.0
 * @access 	public
*/
public function register_developressbar_plugin_settings() {
        // Add a General section
		add_settings_section(
			$this->option_name. '_general',
			__( 'Basic information to start using the plugin', 'developressbar' ),
			array( $this, $this->option_name . '_general_cb' ),
			$this->plugin_name
		);


		foreach ( $this->setting_options as $option ) {

			// Add a numeric field
			add_settings_field(
				$this->option_name . $option,
				$option,
				array( $this, $this->option_name . '_field' ),
				$this->plugin_name,
				$this->option_name . '_general',
				array(
					'label_for' => $this->option_name . $option,
				),
			);

			$args = array(
				'type'              => 'string',
				'sanitize_callback' => 'sanitize_text_field',
				'default'           => null,
			);
			// Register the numeric field.
			register_setting( $this->plugin_name, $this->option_name . $option, $args );

		}

	}

	/**
 * Render the text for the general section
 *
 * @since  	1.0.0
 * @access 	public
*/
public function developressbar_setting_general_cb() {
		echo '<p>' . __( 'From this page you can edit the buttons, you can add the anchor text and the destination link. I suggest you add the complete protocol link, for example: http://www.your-site.xxx', 'developressbar' ) . '</p>';

	}

	/**
 * Render the number input for this plugin
 *
 * @since  1.0.0
 * @access public
 */
public function developressbar_setting_field( $args ) {
		$option_name = $args['label_for'];
		$val         = get_option( $option_name );
		echo '<input type="text" name="' . esc_attr( $option_name ) . '" id="' . esc_attr( $option_name ) . '" value="' . esc_attr( $val ) . '"> ';
	}

/**
 * Include the setting page
 *
 * @since  1.0.0
 * @access public
*/
function developressbar_init(){
	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}
	include DEVELOPRESSBAR_PATH . 'admin/partials/developress_sticky_footer_bar-admin-display.php' ;

}

public function developressbar_plugin_setup_menu(){
		add_menu_page( 'Footer Bar Developress - Settings page', 'Footer Bar _ Developress', 'manage_options', 'developressbar', array($this, 'developressbar_init'), 'dashicons-admin-tools' );

	}
	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Developress_sticky_footer_bar_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Developress_sticky_footer_bar_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/developress_sticky_footer_bar-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Developress_sticky_footer_bar_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Developress_sticky_footer_bar_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/developress_sticky_footer_bar-admin.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Get option name.
	 *
	 * @since  	1.0.0
	 * @access 	public
	*/
	public function get_option_name() {
		return $this->option_name;
	}

	public function get_setting_options() {
		return $this->setting_options;
	}
}
