<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       developress.it/roberto_paolucci
 * @since      1.0.0
 *
 * @package    Developress_sticky_footer_bar
 * @subpackage Developress_sticky_footer_bar/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Developress_sticky_footer_bar
 * @subpackage Developress_sticky_footer_bar/public
 * @author     Roberto Paolucci <robertopaolucci805@gmail.com>
 */
class Developress_sticky_footer_bar_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Option Name.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $option_name    The current option name;
	 */
	private $option_name;

	/**
	 * Setting Options List
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $setting_options    The current setting_options list;
	 */
	private $setting_options;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
		if ( class_exists( 'Developress_sticky_footer_bar_Admin' ) ) {
			$plugin_admin          = new Developress_sticky_footer_bar_Admin( $plugin_name, $version );
			$this->option_name     = $plugin_admin->get_option_name();
			$this->setting_options = $plugin_admin->get_setting_options();
		}
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Developress_sticky_footer_bar_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Developress_sticky_footer_bar_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/developress_sticky_footer_bar-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Developress_sticky_footer_bar_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Developress_sticky_footer_bar_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/developress_sticky_footer_bar-public.js', array( 'jquery' ), $this->version, false );

	}

	function develop_footer_sticky_bar_options() {

		$options = array();
		if ( isset( $this->setting_options ) && ! empty( $this->setting_options ) ) {

			$option_index = 0;
			$options_count = count( $this->setting_options );
			for ( $i = 0; $i < $options_count; $i += 2 ) {

				$option_index++;
				array_push(
					$options,
					array(
						'url'  => get_option( $this->option_name . 'url_' . $option_index ),
						'text' => get_option( $this->option_name . 'text_' . $option_index ),

					),
				);
			}
		}
		return $options;

	}

	public function imw_footer_sticky_bar() {

		$options = $this->develop_footer_sticky_bar_options();
		if ( ! empty( $options ) ) {

			?>
			<style>
				#cta-fixed {
			  -webkit-box-shadow: 3px 3px 13px 6px rgba(45,87,163, 0.3);  /* Safari 3-4, iOS 4.0.2 - 4.2, Android 2.3+ */
			  -moz-box-shadow:    3px 3px 13px 6px rgba(45,87,163, 0.3);  /* Firefox 3.5 - 3.6 */
			  box-shadow:         3px 3px 13px 6px rgba(45,87,163, 0.3);
			  position:fixed;
			  bottom: 0;
			  left: 0;
			  width: 100%;
			  margin-bottom:0px;
			  color: #FFFFFF;
			  font-weight:600;
			  text-align: center;
			  font-size: 14px;
			  letter-spacing:2px;
					text-transform:uppercase;
			}
			#cta-fixed a {
			  color: #fff; !important
			  text-decoration: none;
			}
				.button-cta-fixed {
				  border-radius:0;
				  font-family: 'Fira Sans', sans-serif;
				  padding:1em 1.5em 1em 1.5em;
				 -webkit-transition: all 0.2s ease-in-out;
				 -moz-transition: all 0.2s ease-in-out;
				 -o-transition: all 0.2s ease-in-out;
				 transition: all 0.2s ease-in-out;
				 background: #2d57a3;
				}

				.button-cta-fixed:hover {
					border-radius:25px;
				  font-family: 'Fira Sans', sans-serif;
				  background-color: #1e4895;
				 -webkit-transition: all 0.2s ease-in-out;
				 -moz-transition: all 0.2s ease-in-out;
				 -o-transition: all 0.2s ease-in-out;
				  transition: all 0.2s ease-in-out;
				  padding:1em 1.5em 0.8em 1.5em;
			}

			@media only screen and (min-width: 20px) {
			    /* Style adjustments for viewports that meet the condition */

			 #cta-fixed {
			  	background: #ededed;
			  	z-index:999;
			    padding: 1.7em 0 1.7em 0;
			  }


				.button-cta-fixed {
			        border-style: solid;
			        border-width: 1px;
			        border-color: #ffffff;
				}
			}

			@media only screen and (min-width: 768px) {
			    /* Style adjustments for viewports that meet the condition */

			  #cta-fixed {
			  	background-color:#d1e2f2;
			    padding: 1.3em 0 1.3em 0;
			  }

				.button-cta-fixed {
				  background: #2d57a3;
				}
			}

			@media only screen and (min-width: 1024px) {
				#cta-fixed {
			  		z-index:1000;
					}

				.button-cta-fixed {
			        border-style: solid;
			        border-width: 0px;
			        border-color: #ffffff;
							background: #2d57a3;
				}

			}

			</style>

			<div id="cta-fixed">
				<?php
				foreach ( $options as $option ) {
					$url = ! empty( $option['url'] ) ? $option['url'] : '#';
					$check_text_input = esc_html( $option['text'] );
					if (!empty($check_text_input)) {
					?>
					<a href="<?php echo esc_url( $url ); ?>" class="button-cta-fixed">
						<?php echo esc_html( $option['text'] ); ?>
					</a>&nbsp;

					<?php
					}
				}

				?>

			</div>

			<?php

		}
		add_action( 'wp_footer', 'imw_footer_sticky_bar', 100 );
	}

}
